@@ -3,6 +3,8 @@
 #ifndef __LXC_COMMANDS_UTILS_H
 #define __LXC_COMMANDS_UTILS_H
 
+#include "config.h"
+
 #include <stdio.h>
 
 #include "state.h"
@@ -60,6 +62,9 @@ __hidden extern int lxc_add_state_client(int state_client_fd, struct lxc_handler
  *                                     >= 0 client fd
  */
 __hidden extern int lxc_cmd_connect(const char *name, const char *lxcpath,
-				    const char *hashed_sock_name, const char *suffix);
+				    const char *hashed_sock_name, const char *suffix, int rcv_timeout);
 
+__hidden extern void lxc_cmd_notify_state_listeners(const char *name,
+                                                    const char *lxcpath,
+                                                    lxc_state_t state);
 #endif /* __LXC_COMMANDS_UTILS_H */
