@@ -3,6 +3,8 @@
 #ifndef __LXC_CONFILE_UTILS_H
 #define __LXC_CONFILE_UTILS_H
 
+#include "config.h"
+
 #include <stdbool.h>
 
 #include "compiler.h"
@@ -31,12 +33,11 @@ __hidden extern int parse_idmaps(const char *idmap, char *type, unsigned long *n
 				 unsigned long *hostid, unsigned long *range);
 
 __hidden extern bool lxc_config_value_empty(const char *value);
-__hidden extern struct lxc_netdev *lxc_network_add(struct lxc_list *networks, int idx, bool tail);
 __hidden extern struct lxc_netdev *lxc_get_netdev_by_idx(struct lxc_conf *conf, unsigned int idx,
 							 bool allocate);
 __hidden extern void lxc_log_configured_netdevs(const struct lxc_conf *conf);
 __hidden extern bool lxc_remove_nic_by_idx(struct lxc_conf *conf, unsigned int idx);
-__hidden extern void lxc_free_networks(struct lxc_list *networks);
+__hidden extern void lxc_free_networks(struct lxc_conf *conf);
 __hidden extern void lxc_clear_netdev(struct lxc_netdev *netdev);
 __hidden extern int lxc_veth_mode_to_flag(int *mode, const char *value);
 __hidden extern char *lxc_veth_flag_to_mode(int mode);
