@@ -1,8 +1,7 @@
 /* SPDX-License-Identifier: LGPL-2.1+ */
 
-#ifndef _GNU_SOURCE
-#define _GNU_SOURCE 1
-#endif
+#include "config.h"
+
 #include <errno.h>
 #include <stdlib.h>
 #include <sys/mount.h>
@@ -11,7 +10,6 @@
 
 #include "compiler.h"
 #include "conf.h"
-#include "config.h"
 #include "log.h"
 #include "lsm.h"
 
