@@ -1,8 +1,7 @@
 /* SPDX-License-Identifier: LGPL-2.1+ */
 
-#ifndef _GNU_SOURCE
-#define _GNU_SOURCE 1
-#endif
+#include "config.h"
+
 #include <errno.h>
 #include <fcntl.h>
 #include <malloc.h>
@@ -12,9 +11,8 @@
 #include <sys/file.h>
 #include <unistd.h>
 
-#include <lxc/lxccontainer.h>
+#include "lxc.h"
 
-#include "config.h"
 #include "log.h"
 #include "lxclock.h"
 #include "memory_utils.h"
@@ -107,7 +105,7 @@ static char *lxclock_name(const char *p, const char *n)
 	if (ret < 0)
 		return NULL;
 
-	ret = mkdir_p(dest, 0755);
+	ret = lxc_mkdir_p(dest, 0755);
 	if (ret < 0)
 		return NULL;
 
