@@ -3,6 +3,8 @@
 #ifndef __LXC_STORAGE_UTILS_H
 #define __LXC_STORAGE_UTILS_H
 
+#include "config.h"
+
 #include <stdbool.h>
 #include <stdint.h>
 #include <string.h>
@@ -34,8 +36,7 @@ __hidden extern int find_fstype_cb(char *buffer, void *data);
 __hidden extern const char *linkderef(const char *path, char *dest);
 __hidden extern bool unpriv_snap_allowed(struct lxc_storage *b, const char *t, bool snap,
 					 bool maybesnap);
-__hidden extern uint64_t get_fssize(char *s);
-__hidden extern bool is_valid_storage_type(const char *type);
+extern bool lxc_is_valid_storage_type(const char *type);
 __hidden extern int storage_destroy_wrapper(void *data);
 
 #endif /* __LXC_STORAGE_UTILS_H */
