@@ -85,6 +85,8 @@ Options:\n\
 	.parser   = my_parser,
 	.checker  = NULL,
 	.timeout = 60,
+	.log_priority = "ERROR",
+	.log_file     = "none",
 };
 
 static int list_contains_entry(char *str_ptr, struct lxc_list *p1) {
@@ -304,7 +306,8 @@ static int toss_list(struct lxc_list *c_groups_list)
 	return 1;
 }
 
-int main(int argc, char *argv[])
+int __attribute__((weak, alias("lxc_autostart_main"))) main(int argc, char *argv[]);
+int lxc_autostart_main(int argc, char *argv[])
 {
 	int count = 0, failed = 0, i = 0, ret = 0;
 	struct lxc_list *cmd_group;
@@ -503,7 +506,7 @@ int main(int argc, char *argv[])
 	toss_list(cmd_groups_list);
 	free(containers);
 
-	if (failed == count)
+	if (failed > 0 && failed == count)
 		exit(EXIT_FAILURE);	/* Total failure */
 	else if (failed > 0)
 		exit(2);	/* Partial failure */
