@@ -188,7 +188,8 @@ static bool do_destroy_with_snapshots(struct lxc_container *c)
 	return bret;
 }
 
-int main(int argc, char *argv[])
+int __attribute__((weak, alias("lxc_destroy_main"))) main(int argc, char *argv[]);
+int lxc_destroy_main(int argc, char *argv[])
 {
 	struct lxc_container *c;
 	struct lxc_log log;
